package com.mortals.xhx.module.datum.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.*;
import com.mortals.xhx.module.datum.model.DatumInfoFieldEntity;
import com.mortals.xhx.module.datum.model.DatumInfoFieldQuery;
import com.mortals.xhx.module.datum.service.DatumInfoFieldService;
import com.mortals.xhx.module.matter.model.MatterDatumPrintEntity;
import com.mortals.xhx.module.matter.model.MatterDatumPrintQuery;
import com.mortals.xhx.module.matter.service.MatterDatumPrintService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 填单用户信息字段
 *
 * @author zxfei
 * @date 2024-04-23
 */
@RestController
@RequestMapping("datum/info/field")
public class DatumInfoFieldController extends BaseCRUDJsonBodyMappingController<DatumInfoFieldService, DatumInfoFieldEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private MatterDatumPrintService datumPrintService;


    public DatumInfoFieldController() {
        super.setModuleDesc("填单用户信息字段");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "fieldType", FieldTypeEnum.getEnumMap());
        this.addDict(model, "dataType", DataTypeEnum.getEnumMap());
        this.addDict(model, "fieldNull", FieldNullEnum.getEnumMap());
        this.addDict(model, "isList", IsListEnum.getEnumMap());
        super.init(model, context);
    }


    /**
     * 解析保存用户所有表单
     *
     * @param query
     * @return
     */
    @PostMapping(value = "parseForm")
    @UnAuth
    public Rest<Object> parseForm(@RequestBody DatumInfoFieldEntity query) {
        Map<String, Object> model = new HashMap<>();
        Context context = this.getContext();
        String busiDesc = "解析保存" + this.getModuleDesc();
        try {
            List<MatterDatumPrintEntity> datumPrintEntities = datumPrintService.find(new MatterDatumPrintQuery());
            for (MatterDatumPrintEntity datumPrintEntity : datumPrintEntities) {
                if (!ObjectUtils.isEmpty(datumPrintEntity.getFormContent())) {
                    Rest<List<DatumInfoFieldEntity>> rest = this.service.parseFormContent(datumPrintEntity, context);
                    if (rest.getCode() == YesNoEnum.YES.getValue() && !ObjectUtils.isEmpty(rest.getData())) {
                        this.service.save(rest.getData(), getContext());
                    }
                }
            }
            recordSysLog(request, busiDesc + " 【成功】");
        } catch (Exception e) {
            this.doException(request, busiDesc, model, e);
            return Rest.fail(e.getMessage());
        }
        return Rest.ok(model);
    }

    /**
     * 去重列表
     *
     * @param query
     * @return
     */
    @PostMapping(value = "distinctList")
    @UnAuth
    public Rest<Object> distinctList(@RequestBody DatumInfoFieldQuery query) {
        Map<String, Object> model = new HashMap<>();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        try {
            Rest<List<DatumInfoFieldEntity>> rest = this.service.distinctList(query, context);
            model.put(KEY_RESULT_DATA, rest.getData());
            recordSysLog(request, busiDesc + " 【成功】");
        } catch (Exception e) {
            this.doException(request, busiDesc, model, e);
            return Rest.fail(e.getMessage());
        }
        this.init(model, context);

        return Rest.ok(model);
    }


}