package com.mortals.xhx.module.h5;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.IUser;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.feign.base.pdu.SitePdu;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.module.h5.pdu.MobileCodePdu;
import com.mortals.xhx.module.user.model.UserFillHistoryEntity;
import com.mortals.xhx.module.user.model.UserFillHistoryQuery;
import com.mortals.xhx.module.user.service.UserFillHistoryService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 终端访问接口
 */
@RestController
@RequestMapping("terminal/h5")
@Slf4j
public class TerminalController extends BaseJsonBodyController {

    /** php接口访问地址 */
    @Value("${phpServer:http://112.19.80.237:8090}")
    private String phpServer;
    @Autowired
    private UserFillHistoryService userFillHistoryService;

    /**
     * 发送手机验证码
     * @param pdu
     * @return
     */
    @PostMapping({"mobile/code/send"})
    @UnAuth
    public Rest<Object> msgCodeSend(@RequestBody MobileCodePdu pdu) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "获取手机验证码";

        int code = 1;
        try {
            String url = phpServer + "/wechat/homebase/msgCode";
            String resp = HttpUtil.createPost(url).header("siteid",pdu.getSiteId()).form("phone",pdu.getPhone()).execute().body();
            JSONObject jsonObject = JSONObject.parseObject(resp);
            if(jsonObject.getIntValue("code")==1){
                model.put("message_info", busiDesc + "成功");
            }else {
                code = -1;
                model.put("message_info", jsonObject.getString("msg"));
            }
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            model.put("message_info", "手机验证码接口调用异常");
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 验证手机号
     * @param pdu
     * @return
     */
    @PostMapping({"mobile/code/check"})
    @UnAuth
    public Rest<Object> msgCodeCheck(@RequestBody MobileCodePdu pdu) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "校验手机验证码";

        int code = 1;
        try {
            String url = phpServer + "/wechat/homebase/checkMsgCode";
            Map<String, Object> paramsMap = new HashMap<>();
            paramsMap.put("phone",pdu.getPhone());
            paramsMap.put("code",pdu.getCode());
            String resp = HttpUtil.createPost(url).header("siteid",pdu.getSiteId()).form(paramsMap).execute().body();
            JSONObject jsonObject = JSONObject.parseObject(resp);
            if(jsonObject.getIntValue("code")==1){
                model.put("message_info", busiDesc + "成功");
            }else {
                code = -1;
                model.put("message_info", jsonObject.getString("msg"));
            }
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            model.put("message_info", "手机验证码校验接口调用异常");
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 获取我的填单列表
     * @param query
     * @return
     */
    @PostMapping({"fill/history/delete"})
    @UnAuth
    public Rest<Object> deleteHistoryList(@RequestBody UserFillHistoryEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "填单设备终端用户删除填单记录";

        int code = 1;
        try {
            if(query.getId()==null){
                throw new AppException("请选择一条记录");
            }
            UserFillHistoryEntity entity = userFillHistoryService.get(query.getId());
            if(entity==null){
                throw new AppException("记录不存在或者已经删除");
            }
            List<UserFillHistoryEntity> list = userFillHistoryService.find(new UserFillHistoryQuery().materialId(entity.getMaterialId()).openId(entity.getOpenId()));
            List<Long> idList = list.stream().map(UserFillHistoryEntity::getId).collect(Collectors.toList());
            userFillHistoryService.remove(idList,null);
            model.put("message_info", busiDesc + "成功");

            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            model.put("message_info", "填单设备终端用户删除填单记录异常");
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 获取我的填单列表
     * @param query
     * @return
     */
    @PostMapping({"fill/history/list"})
    @UnAuth
    public Rest<Object> historyList(@RequestBody UserFillHistoryEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "填单设备终端用户获取填单记录列表";

        int code = 1;
        try {
            if(StringUtils.isNotEmpty(query.getMobile())||StringUtils.isNotEmpty(query.getIdCard())) {
                PageInfo pageInfo = this.buildPageInfo(query);
                if(CollectionUtils.isEmpty(query.getOrderColList())){
                    query.setOrderColList(Arrays.asList(new OrderCol("createTime", OrderCol.DESCENDING)));
                }
                List<UserFillHistoryEntity> listAll = userFillHistoryService.find(query);
                List<Long> materialId = new ArrayList<>();
                List<Long> idList = new ArrayList<>();
                for(UserFillHistoryEntity entity:listAll){
                    if(!materialId.contains(entity.getMaterialId())){
                        materialId.add(entity.getMaterialId());
                        idList.add(entity.getId());
                    }
                }
                query.setIdList(idList);
                Result<UserFillHistoryEntity> result = userFillHistoryService.find(query, pageInfo, this.getContext());
                model.put("data", result.getList());
                model.put("pageInfo", result.getPageInfo());
                this.parsePageInfo(model, result.getPageInfo());
                model.put("message_info", busiDesc + "成功");
            }else {
                throw new AppException("请输入手机号码或者身份证号码");
            }
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            model.put("message_info", "填单设备终端用户获取填单记录列表异常");
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }


    protected PageInfo buildPageInfo(UserFillHistoryEntity query) {
        PageInfo pageInfo = new PageInfo();
        if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getPage())) {
            pageInfo.setCurrPage(query.getPage());
        }

        if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getSize())) {
            pageInfo.setPrePageResult(query.getSize());
        }

        if (ObjectUtils.isEmpty(query.getOrderColList())) {
            query.setOrderColList(Arrays.asList(new OrderCol("id", "desc")));
        }

        return pageInfo;
    }

    protected void parsePageInfo(Map<String, Object> model, PageInfo pageInfo) {
        model.put("total", pageInfo.getTotalResult());
        model.put("per_page", pageInfo.getPrePageResult());
        model.put("current_page", pageInfo.getCurrPage());
        model.put("last_page", pageInfo.getTotalPage());
        model.put("pageInfo", pageInfo);
    }


    public static void main(String[] args) {
        try {
            String url = "http://192.168.0.98:8090" + "/wechat/homebase/msgCode";
            Map<String, String> header = new HashMap<>();
            header.put("siteid","1");
            Map<String, String> paramsMap = new HashMap<>();
            paramsMap.put("phone","kYaxRIs67vzhGBdE6Vz74g==");
            String resp = resp = cn.hutool.http.HttpUtil.createPost(url).header("siteid","1").form("phone","kYaxRIs67vzhGBdE6Vz74g==").execute().body();
            System.out.println("==============================");
            System.out.println(resp);
        }catch (Exception e){

        }

    }
}
